package com.xunmei.system.mapper;


import com.baomidou.mybatisplus.core.mapper.BaseMapper;
import com.xunmei.system.api.domain.SysUserInformation;
import org.apache.ibatis.annotations.Mapper;

import java.util.List;

/**
 * 【请填写功能名称】Mapper接口
 *
 * @author xunmei
 * @date 2023-08-18
 */
@Mapper
public interface SysUserInformationMapper extends BaseMapper<SysUserInformation> {
    /**
     * 查询【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 【请填写功能名称】
     */
     SysUserInformation selectSysUserInformationById(Long id);
 SysUserInformation  getInformationByUserId(Long userId);
    /**
     * 查询【请填写功能名称】列表
     *
     * @param sysUserInformation 【请填写功能名称】
     * @return 【请填写功能名称】集合
     */
     List<SysUserInformation> selectSysUserInformationList(SysUserInformation sysUserInformation);

    /**
     * 新增【请填写功能名称】
     *
     * @param sysUserInformation 【请填写功能名称】
     * @return 结果
     */
     int insertSysUserInformation(SysUserInformation sysUserInformation);

    /**
     * 修改【请填写功能名称】
     *
     * @param sysUserInformation 【请填写功能名称】
     * @return 结果
     */
     int updateSysUserInformation(SysUserInformation sysUserInformation);

    /**
     * 删除【请填写功能名称】
     *
     * @param id 【请填写功能名称】主键
     * @return 结果
     */
     int deleteSysUserInformationById(Long id);

    /**
     * 批量删除【请填写功能名称】
     *
     * @param ids 需要删除的数据主键集合
     * @return 结果
     */
     int deleteSysUserInformationByIds(Long[] ids);
}
